==> ejc-outcontract-api-3.0.0-20220107.014412-4-sources.jar: com/ejianc/foundation/outcontract/vo/ChangeOutcontractSubcontractUnitPriceVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 变更分包工程综合单价计价表
 * 
 * @author generator
 * 
 */
public class ChangeOutcontractSubcontractUnitPriceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long changeOutcontractId; // 变更合同id
    private String listCode; // 清单编号
    private String project; // 项目
    private String jobContent; // 工作内容
    private String projectCharacteristic; // 项目特征
    private String unit; // 单位
    private BigDecimal engineeringQuantity; // 工程量
    private BigDecimal comprehensiveUnitPrice; // 综合单价
    private BigDecimal laborCost; // 人工费
    private BigDecimal mainMaterialCost; // 主材费
    private BigDecimal materialLoss; // 材料损耗
    private BigDecimal auxiliaryMaterialCost; // 辅材费
    private BigDecimal machineryCost; // 机械费
    private BigDecimal managementCost; // 管理费
    private BigDecimal profit; // 利润
    private BigDecimal paidGovernmentCost; // 规费
    private BigDecimal tax; // 税金
    private String mainMaterialBrand; // 主材品牌
    private String remark; // 备注
    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public String getListCode() {
        return listCode;
    }

    public void setListCode(String listCode) {
        this.listCode = listCode;
    }
    public String getProject() {
        return project;
    }

    public void setProject(String project) {
        this.project = project;
    }
    public String getJobContent() {
        return jobContent;
    }

    public void setJobContent(String jobContent) {
        this.jobContent = jobContent;
    }
    public String getProjectCharacteristic() {
        return projectCharacteristic;
    }

    public void setProjectCharacteristic(String projectCharacteristic) {
        this.projectCharacteristic = projectCharacteristic;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getEngineeringQuantity() {
        return engineeringQuantity;
    }

    public void setEngineeringQuantity(BigDecimal engineeringQuantity) {
        this.engineeringQuantity = engineeringQuantity;
    }
    public BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    public void setComprehensiveUnitPrice(BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    public BigDecimal getLaborCost() {
        return laborCost;
    }

    public void setLaborCost(BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    public BigDecimal getMainMaterialCost() {
        return mainMaterialCost;
    }

    public void setMainMaterialCost(BigDecimal mainMaterialCost) {
        this.mainMaterialCost = mainMaterialCost;
    }
    public BigDecimal getMaterialLoss() {
        return materialLoss;
    }

    public void setMaterialLoss(BigDecimal materialLoss) {
        this.materialLoss = materialLoss;
    }
    public BigDecimal getAuxiliaryMaterialCost() {
        return auxiliaryMaterialCost;
    }

    public void setAuxiliaryMaterialCost(BigDecimal auxiliaryMaterialCost) {
        this.auxiliaryMaterialCost = auxiliaryMaterialCost;
    }
    public BigDecimal getMachineryCost() {
        return machineryCost;
    }

    public void setMachineryCost(BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    public BigDecimal getManagementCost() {
        return managementCost;
    }

    public void setManagementCost(BigDecimal managementCost) {
        this.managementCost = managementCost;
    }
    public BigDecimal getProfit() {
        return profit;
    }

    public void setProfit(BigDecimal profit) {
        this.profit = profit;
    }
    public BigDecimal getPaidGovernmentCost() {
        return paidGovernmentCost;
    }

    public void setPaidGovernmentCost(BigDecimal paidGovernmentCost) {
        this.paidGovernmentCost = paidGovernmentCost;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMainMaterialBrand() {
        return mainMaterialBrand;
    }

    public void setMainMaterialBrand(String mainMaterialBrand) {
        this.mainMaterialBrand = mainMaterialBrand;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-api-3.0.0-20220507.061725-84-sources.jar: com/ejianc/foundation/outcontract/vo/ChangeOutcontractSubcontractUnitPriceVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.math.BigDecimal;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 变更分包工程综合单价计价表
 * 
 * @author generator
 * 
 */
public class ChangeOutcontractSubcontractUnitPriceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long changeOutcontractId; // 变更合同id
    private String listCode; // 清单编号
    private String project; // 项目
    private String jobContent; // 工作内容
    private String projectCharacteristic; // 项目特征
    private String unit; // 单位
    private BigDecimal engineeringQuantity; // 工程量
    private BigDecimal comprehensiveUnitPrice; // 综合单价
    private BigDecimal totalPrice; // 合计
    private BigDecimal laborCost; // 人工费
    private BigDecimal mainMaterialCost; // 主材费
    private BigDecimal materialLoss; // 材料损耗
    private BigDecimal auxiliaryMaterialCost; // 辅材费
    private BigDecimal machineryCost; // 机械费
    private BigDecimal managementCost; // 管理费
    private BigDecimal profit; // 利润
    private BigDecimal paidGovernmentCost; // 规费
    private BigDecimal tax; // 税金
    private String mainMaterialBrand; // 主材品牌
    private String remark; // 备注
    private Long pid; // 父级节点id
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息
    
    private List<ChangeOutcontractSubcontractUnitPriceVO> children;
    
    
    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public String getListCode() {
        return listCode;
    }

    public void setListCode(String listCode) {
        this.listCode = listCode;
    }
    public String getProject() {
        return project;
    }

    public void setProject(String project) {
        this.project = project;
    }
    public String getJobContent() {
        return jobContent;
    }

    public void setJobContent(String jobContent) {
        this.jobContent = jobContent;
    }
    public String getProjectCharacteristic() {
        return projectCharacteristic;
    }

    public void setProjectCharacteristic(String projectCharacteristic) {
        this.projectCharacteristic = projectCharacteristic;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getEngineeringQuantity() {
        return engineeringQuantity;
    }

    public void setEngineeringQuantity(BigDecimal engineeringQuantity) {
        this.engineeringQuantity = engineeringQuantity;
    }
    public BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    public void setComprehensiveUnitPrice(BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    public BigDecimal getLaborCost() {
        return laborCost;
    }

    public void setLaborCost(BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    public BigDecimal getMainMaterialCost() {
        return mainMaterialCost;
    }

    public void setMainMaterialCost(BigDecimal mainMaterialCost) {
        this.mainMaterialCost = mainMaterialCost;
    }
    public BigDecimal getMaterialLoss() {
        return materialLoss;
    }

    public void setMaterialLoss(BigDecimal materialLoss) {
        this.materialLoss = materialLoss;
    }
    public BigDecimal getAuxiliaryMaterialCost() {
        return auxiliaryMaterialCost;
    }

    public void setAuxiliaryMaterialCost(BigDecimal auxiliaryMaterialCost) {
        this.auxiliaryMaterialCost = auxiliaryMaterialCost;
    }
    public BigDecimal getMachineryCost() {
        return machineryCost;
    }

    public void setMachineryCost(BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    public BigDecimal getManagementCost() {
        return managementCost;
    }

    public void setManagementCost(BigDecimal managementCost) {
        this.managementCost = managementCost;
    }
    public BigDecimal getProfit() {
        return profit;
    }

    public void setProfit(BigDecimal profit) {
        this.profit = profit;
    }
    public BigDecimal getPaidGovernmentCost() {
        return paidGovernmentCost;
    }

    public void setPaidGovernmentCost(BigDecimal paidGovernmentCost) {
        this.paidGovernmentCost = paidGovernmentCost;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMainMaterialBrand() {
        return mainMaterialBrand;
    }

    public void setMainMaterialBrand(String mainMaterialBrand) {
        this.mainMaterialBrand = mainMaterialBrand;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public Long getPid() {
		return pid;
	}

	public void setPid(Long pid) {
		this.pid = pid;
	}

	public String getInnercode() {
		return innercode;
	}

	public void setInnercode(String innercode) {
		this.innercode = innercode;
	}

	public BigDecimal getTotalPrice() {
		return totalPrice;
	}

	public void setTotalPrice(BigDecimal totalPrice) {
		this.totalPrice = totalPrice;
	}

	public String getErrorMsg() {
		return errorMsg;
	}

	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}

	public List<ChangeOutcontractSubcontractUnitPriceVO> getChildren() {
		return children;
	}

	public void setChildren(List<ChangeOutcontractSubcontractUnitPriceVO> children) {
		this.children = children;
	}
    
}
